@@ -2,7 +2,7 @@
 from __future__ import print_function
 
 import re
-
+from math import log10
 from .parameter import Parameters
 
 
@@ -12,50 +12,62 @@ def alphanumeric_sort(s, _nsre=re.compile('([0-9]+)')):
             for text in re.split(_nsre, s)]
 
 
-def getfloat_attr(obj, attr, fmt='%.3f'):
+def getfloat_attr(obj, attr, length=11):
     """Format an attribute of an object for printing."""
     val = getattr(obj, attr, None)
     if val is None:
         return 'unknown'
-    if isinstance(val, int):
+    elif isinstance(val, int):
         return '%d' % val
-    if isinstance(val, float):
-        return fmt % val
-    else:
-        return repr(val)
+    elif isinstance(val, float):
+        return gformat(val, length=length).strip()
+    return repr(val)
 
 
 def gformat(val, length=11):
-    """Format a number with '%g'-like format.
+    """Format a number with '%g'-like format, except that
 
-    The return will be length ``length`` (default is 12) and have at
-    least length-6 significant digits.
+        a) the length of the output string will be the requested length.
+        b) positive numbers will have a leading blank.
+        b) the precision will be as high as possible.
+        c) trailing zeros will not be trimmed.
+
+    The precision will typically be length-7.
+
+    Arguments
+    ---------
+    val       value to be formatted
+    length    length of output string
+
+    Returns
+    -------
+    string of specified length.
+
+    Notes
+    ------
+     Positive values will have leading blank.
 
     """
+    try:
+        expon = int(log10(abs(val)))
+    except (OverflowError, ValueError):
+        expon = 0
     length = max(length, 7)
-    fmt = '{0: .%ig}' % (length-6)
-    if isinstance(val, int):
-        out = ('{0: .%ig}' % (length-2)).format(val)
-        if len(out) > length:
-            out = fmt.format(val)
-    else:
-        out = fmt.format(val)
-    if len(out) < length:
-        if 'e' in out:
-            ie = out.find('e')
-            if '.' not in out[:ie]:
-                out = out[:ie] + '.' + out[ie:]
-            out = out.replace('e', '0'*(length-len(out))+'e')
-        else:
-            fmt = '{0: .%ig}' % (length-1)
-            out = fmt.format(val)[:length]
-            if len(out) < length:
-                pad = '0' if '.' in out else ' '
-                out += pad*(length-len(out))
-    return out
+    form = 'e'
+    prec = length - 7
+    if abs(expon) > 99:
+        prec -= 1
+    elif ((expon > 0 and expon < (prec+4)) or
+          (expon <= 0 and -expon < (prec-1))):
+        form = 'f'
+        prec += 4
+        if expon > 0:
+            prec -= expon
+    fmt = '{0: %i.%i%s}' % (length, prec, form)
+    return fmt.format(val)
 
 
-CORREL_HEAD = '[[Correlations]] (unreported correlations are < % .3f)'
+CORREL_HEAD = '[[Correlations]] (unreported correlations are < %.3f)'
 
 
 def fit_report(inpars, modelpars=None, show_correl=True, min_correl=0.1,
@@ -109,6 +121,7 @@ def fit_report(inpars, modelpars=None, show_correl=True, min_correl=0.1,
     add = buff.append
     if result is not None:
         add("[[Fit Statistics]]")
+        add("    # fitting method   = %s" % (result.method))
         add("    # function evals   = %s" % getfloat_attr(result, 'nfev'))
         add("    # data points      = %s" % getfloat_attr(result, 'ndata'))
         add("    # variables        = %s" % getfloat_attr(result, 'nvarys'))
@@ -121,20 +134,20 @@ def fit_report(inpars, modelpars=None, show_correl=True, min_correl=0.1,
     add("[[Variables]]")
     for name in parnames:
         par = params[name]
-        space = ' '*(namelen+1-len(name))
+        space = ' '*(namelen-len(name))
         nout = "%s:%s" % (name, space)
-        inval = '(init= ?)'
+        inval = '(init = ?)'
         if par.init_value is not None:
-            inval = '(init=% .7g)' % par.init_value
+            inval = '(init = %.7g)' % par.init_value
         if modelpars is not None and name in modelpars:
-            inval = '%s, model_value =% .7g' % (inval, modelpars[name].value)
+            inval = '%s, model_value = %.7g' % (inval, modelpars[name].value)
         try:
             sval = gformat(par.value)
         except (TypeError, ValueError):
             sval = 'Non Numeric Value?'
 
         if par.stderr is not None:
-            serr = gformat(par.stderr, length=9)
+            serr = gformat(par.stderr)
 
             try:
                 spercent = '({0:.2%})'.format(abs(par.stderr/par.value))
@@ -145,7 +158,7 @@ def fit_report(inpars, modelpars=None, show_correl=True, min_correl=0.1,
         if par.vary:
             add("    %s %s %s" % (nout, sval, inval))
         elif par.expr is not None:
-            add("    %s %s  == '%s'" % (nout, sval, par.expr))
+            add("    %s %s == '%s'" % (nout, sval, par.expr))
         else:
             add("    %s % .7g (fixed)" % (nout, par.value))
 
@@ -165,9 +178,10 @@ def fit_report(inpars, modelpars=None, show_correl=True, min_correl=0.1,
         sort_correl.reverse()
         if len(sort_correl) > 0:
             add(CORREL_HEAD % min_correl)
+            maxlen = max([len(k) for k in list(correls.keys())])
         for name, val in sort_correl:
-            lspace = max(1, 25 - len(name))
-            add('    C(%s)%s = % .3f ' % (name, (' '*30)[:lspace], val))
+            lspace = max(0, maxlen - len(name))
+            add('    C(%s)%s = % .3f' % (name, (' '*30)[:lspace], val))
     return '\n'.join(buff)
 
 
